@@ -30,11 +30,11 @@ class ReadTestImageV2(Reader):
     def __init__(
         self,
         image_size: int = 100,
-        to_hash_added:int = 0,
+        to_hash_added: int = 0,
         num_of_circles: int = 10,
         return_mask: bool = False,
         return_coordinats: bool = False,
-        return_bbox: bool = False
+        return_bbox: bool = False,
     ):
         """
         TODO
@@ -56,7 +56,7 @@ class ReadTestImageV2(Reader):
         self.return_bbox = return_bbox
         self.num_of_circles = num_of_circles
 
-    def create_test_image(self,row: int) -> dict:
+    def create_test_image(self, row: int) -> dict:
         """
         TODO
 
@@ -130,7 +130,7 @@ class ReadTestImageV2(Reader):
         Returns:
             TODO: TODO
         """
-        
+
         if isinstance(row_or_df, pd.DataFrame):
             imgs = {}
 
@@ -157,7 +157,7 @@ class ReadTestImage(Reader):
         to_hash_added: int = 0,
         return_mask: bool = False,
         return_coordinats: bool = False,
-        return_bbox: bool = False
+        return_bbox: bool = False,
     ):
         """
         TODO
@@ -305,7 +305,7 @@ class ReadFromImageFile(Reader):
     """
     TODO
     """
-    
+
     def __init__(
         self,
         expression,
@@ -354,8 +354,8 @@ class ReadFromImageFile(Reader):
         if start_y < 0:
             shifted_y = -start_y
             start_y = 0
-        end_x = start_x + self.return_image_size
-        end_y = start_y + self.return_image_size
+        end_x = start_x + self.return_image_size - shifted_x
+        end_y = start_y + self.return_image_size - shifted_y
         img = img[start_x:end_x, start_y:end_y]
         if img.shape[0] != self.return_image_size or img.shape[1] != self.return_image_size:
             img_black_boarder = np.zeros(
@@ -443,7 +443,7 @@ class ReadFromWSI(Reader):
     """
     TODO
     """
-    
+
     def __init__(
         self,
         return_image_size,
@@ -452,7 +452,7 @@ class ReadFromWSI(Reader):
         mpp: float = 0.5,
         x_column: str = "__x__",
         y_column: str = "__y__",
-        use_center_coordinates: bool = True
+        use_center_coordinates: bool = True,
     ):
         """
         TODO
@@ -572,7 +572,7 @@ class ReadValueFromCSV(Reader):
     """
     TODO
     """
-    
+
     def __init__(self, expression, interpreter=helper.read_from_row, encoded_values=None):
         """
         TODO
