@@ -175,7 +175,7 @@ class HistoDataset(torch.utils.data.Dataset):
         mode = "png"
         if mode == "png":
             if os.path.exists(path_to_save) == False:
-                os.mkdir(path_to_save)
+                os.makedirs(path_to_save)
 
             # check the output of the first sample
             dataset = self[0]
