@@ -118,14 +118,51 @@ def midog_classification_patches(
         root,
         df_manipulators=manipulators_to_use,
         data_readers=data_reader,
-        feature_readers=data_readers.ReadValueFromCSV(r"{category_id}", encoded_values=[1, 2]),
+        feature_readers=data_readers.ReadValueFromCSV(r"{category_id}", encoded_values=['1', '2']),
         seed=seed,
         pre_transfs=pre_transformation,
         da_transfs=transformation,
     )
     return ds
 
+""" TODO: how the offline dataset was generated
+# MIDOG
+from histodata.datasets import midog
 
+from torchvision import transforms
+
+transform = transforms.Compose([
+    transforms.ToPILImage(),
+    #transforms.Resize(423), # (2*299**2)**0.5 => 423
+    transforms.ToTensor(),
+])
+
+path_midog = '/data/ldap/histopathologic/original_read_only/MIDOG'
+
+ds = midog.midog_classification_patches(path_midog,
+                       transformation=transform,
+                       subset='train',
+                       seed=200,
+                       patch_size=423, # (2*299**2)**0.5 => 423,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/MIDOG2/train')
+
+ds = midog.midog_classification_patches(path_midog,
+                       transformation=transform,
+                       subset='valid',
+                       seed=200,
+                       patch_size=423, # (2*299**2)**0.5 => 423,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/MIDOG2/valid')
+
+ds = midog.midog_classification_patches(path_midog,
+                       transformation=transform,
+                       subset='test',
+                       seed=200,
+                       patch_size=423, # (2*299**2)**0.5 => 423,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/MIDOG2/test')
+"""
 def midog_classification_patches_preprocessed(
     root: str,  # '/data/ldap/histopathologic/original_read_only/MIDOG2/'
     transformation: O[U[Callable, Sequence[Callable]]] = None,
