@@ -104,6 +104,14 @@ class PCAM(Dataset):
 
         return lens
 
+    def get_feature_for_all_rows(self):
+        labels = []
+        with File(self.labels_hdf5_filepath, "r") as db:
+            for idx in range(len(self)):
+                label = db[self.labels_key][idx][0][0][0]  # TODO make it nice
+                labels.append(label)
+        return labels
+    
     def __getitem__(self, idx: int) -> dict:
         """
         TODO
